body {
	line-height: 1.7;
	// color: lighten($black, 30%);
	color: lighten($black, 50%);
	font-weight: 300;
	font-size: $font-size-base;
	font-family: $font-family-sans-serif;
}
::-moz-selection { 
	background: $black;
	color: $white;
}
::selection { 
	background: $black;
	color: $white;
}
a {
	transition: .3s all ease;
	&:hover {
		text-decoration: none;
	}
}
h1, h2, h3, h4, h5, h6 {
	color: $black;
}

.text-black {
	color: $black!important;
}
.bg-black {
	background: $black!important;
}

.site-wrap {
	&:before {
		transition: .3s all ease-in-out;
		background: rgba(0,0,0,.6);
		content: "";
		position: absolute;
		z-index: 2000;
		top: 0;
		left: 0;
		right: 0;
		bottom: 0;
		opacity: 0;
		visibility: hidden;
	}
	.offcanvas-menu & {
		position: absolute;
		height: 100%;
		width: 100%;
		z-index: 2;
		overflow: hidden;
		
		&:before {
			opacity: 1;
			visibility: visible;
		}
	}
}

.btn {
	border-width: 2px;
	&:active, &:focus {
		outline: none;
		box-shadow: none!important;
	}
	&.btn-lg {
		padding: 10px 20px;
		font-size: 16px;
	}
	&.btn-primary {
		color: $white;
		&:hover, &:focus, &:active {
			color: $black;
			background-color: transparent!important;
		}
	}
}

.bg-black {
	background: $black;
}
.form-control {
	height: 47px;
	&:active, &:focus {
		border-color: $primary;
	}
	&:hover, &:active, &:focus {
		box-shadow: none!important;
	}
}

.site-section {
	padding: 2.5em 0;
	@include media-breakpoint-up(md) {
		padding: 5em 0;
	}

	&.site-section-sm {
		padding: 4em 0;
	}
}

.site-section-heading {
	font-size: 30px;
	color: $gray-1;
	position: relative;
	&:before {
		content: "";
		left: 0%;
		top: 0;
		position: absolute;
		width: 40px;
		height: 2px;
		background: $primary;
	}
	&.text-center {
		&:before {
			content: "";
			left: 50%;
			top: 0;
			transform: translateX(-50%);
			position: absolute;
			width: 40px;
			height: 2px;
			background: $primary;
		}	
	}
	
}

.border-top {
	border-top: 1px solid $gray-4!important;
}

.site-footer {
	padding: 4em 0;
	background: lighten($black, 20%);
	p {
		color: lighten($black, 45%); 
	}
	h2,h3,h4,h5 {
		color: $white;
	}
	a {
		color: lighten($black, 60%); 
		&:hover {
			color: lighten($black, 100%); 
		}
	}
	ul {
		li {
			margin-bottom: 10px;
		}
	}
	.footer-heading {
		font-size: 20px;
		color: $white;
	}
}

.bg-text-line {
  display: inline;
  background: $black;
  box-shadow: 20px 0 0 $black, -20px 0 0 $black;
}

.bg-image {
	background-size: cover;
	background-repeat: no-rpeeat;
	overflow: hidden;
	&.center {
		background-position: top center;
	}
	&.fixed {
		background-position: fixed!important;
	}
	&.overlay, &.overlay-primary, &.overlay-info, &.overlay-success, &.overlay-warning {
		position: relative;
		&:before {
			content: "";
			position: absolute;
			top: 0; bottom: 0; right: 0; left: 0;
		}
	}
	&.overlay {
		&:before {
			background: rgba($black, .4);
		}
	}
	&.overlay-primary {
		&:before {
			background: rgba($primary, .9);
		}
	}
	&.overlay-info {
		&:before {
			background: rgba($info, .9);
		}
	}
	&.overlay-success {
		&:before {
			background: rgba($success, .9);
		}
	}
	&.overlay-success {
		&:before {
			background: rgba($warning, .9);
		}
	}
}